@@ -1,16 +1,13 @@
 import pygame
 import math
-import os
 
 import palletts as p
-import accessors as a
+
 
 class text:
-    def __init__(self, color=-1, font=a.monoid, fontSize=10, text=-1):
+    def __init__(self, color=-1, font="/Users/brianmasse/Library/Fonts/Monoid-Retina.ttf", fontSize=10, text=-1):
         self.color = color
-        
-        self.font = self.return_font(font)
-
+        self.font = font
         self.fontSize = fontSize
         self.text = text
 
@@ -19,16 +16,6 @@ class text:
 
         self.default = False
 
-    def return_font(self, font):
-        dir_path = os.path.dirname(os.path.realpath(__file__))
-        p = dir_path + font
-        if os.path.exists( p ):
-            return p
-        elif os.path.exists( font ):
-            return font
-        return dir_path + a.monoid
-
-
     def __reinit__(self, parent):
         self.parent = parent
         if self.color == -1:
