@@ -12,6 +12,7 @@ import axis as ax
 import palletts as p
 import graph_props as m
 
+
 def round_dig(num, base=5, dig=1):
     num = float(num)
     num = num / (math.pow(base, dig))
@@ -100,8 +101,8 @@ class distribution:
 
     def render(self):
         self.domain.render()
-        # self.graph.handler.render_text(self.title, (self.pos[0] + (
-        #     self.size[0] / 2),  self.pos[1] + (self.size[1])), self.pallett.text_RGB, 20)
+        self.graph.handler.render_text(self.title, (self.pos[0] + (
+            self.size[0] / 2),  self.pos[1] + (self.size[1])), self.pallett.text_RGB, 20)
 
         for series in self.series_data:
             series.render()
